@@ -1,2 +1,2 @@
 #[cfg(any(target_arch = "x86_64", target_arch = "x86"))]
-pub(crate) mod x86;
+pub mod x86;
